@@ -1,3 +1,3 @@
 import micromlgen.platforms as platforms
 from micromlgen.micromlgen import port
-from micromlgen.utils import port_testset
\ No newline at end of file
+from micromlgen.utils import port_testset, port_trainset
